==> gtkaml-0.2.1.0.tar.bz2: gtkaml-0.2.1.0/src/GtkamlXmlNamespace.c <==
/* GtkamlXmlNamespace.vala
 * 
 * Copyright (C) 2008 Vlad Grecescu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with main.c; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 *
 * Author:
 *        Vlad Grecescu (b100dian@gmail.com)
 */

#include "GtkamlXmlNamespace.h"




enum  {
	XML_NAMESPACE_DUMMY_PROPERTY
};
static gpointer xml_namespace_parent_class = NULL;
static void xml_namespace_dispose (GObject * obj);



/**
 * an xml namespace, often referred to as 'prefix'
 */
XmlNamespace* xml_namespace_new (void) {
	XmlNamespace * self;
	self = g_object_newv (TYPE_XML_NAMESPACE, 0, NULL);
	return self;
}


static void xml_namespace_class_init (XmlNamespaceClass * klass) {
	xml_namespace_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->dispose = xml_namespace_dispose;
}


static void xml_namespace_init (XmlNamespace * self) {
}


static void xml_namespace_dispose (GObject * obj) {
	XmlNamespace * self;
	self = XML_NAMESPACE (obj);
	self->prefix = (g_free (self->prefix), NULL);
	self->URI = (g_free (self->URI), NULL);
	G_OBJECT_CLASS (xml_namespace_parent_class)->dispose (obj);
}


GType xml_namespace_get_type (void) {
	static GType xml_namespace_type_id = 0;
	if (G_UNLIKELY (xml_namespace_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (XmlNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) xml_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (XmlNamespace), 0, (GInstanceInitFunc) xml_namespace_init };
		xml_namespace_type_id = g_type_register_static (G_TYPE_OBJECT, "XmlNamespace", &g_define_type_info, 0);
	}
	return xml_namespace_type_id;
}

==> gtkaml-0.2.1.1.tar.bz2: gtkaml-0.2.1.1/src/GtkamlXmlNamespace.c <==
/* GtkamlXmlNamespace.vala
 * 
 * Copyright (C) 2008 Vlad Grecescu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with main.c; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 *
 * Author:
 *        Vlad Grecescu (b100dian@gmail.com)
 */

#include "GtkamlXmlNamespace.h"




enum  {
	XML_NAMESPACE_DUMMY_PROPERTY
};
static gpointer xml_namespace_parent_class = NULL;
static void xml_namespace_dispose (GObject * obj);



/**
 * an xml namespace, often referred to as 'prefix'
 */
XmlNamespace* xml_namespace_new (void) {
	XmlNamespace * self;
	self = g_object_newv (TYPE_XML_NAMESPACE, 0, NULL);
	return self;
}


static void xml_namespace_class_init (XmlNamespaceClass * klass) {
	xml_namespace_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->dispose = xml_namespace_dispose;
}


static void xml_namespace_instance_init (XmlNamespace * self) {
}


static void xml_namespace_dispose (GObject * obj) {
	XmlNamespace * self;
	self = XML_NAMESPACE (obj);
	self->prefix = (g_free (self->prefix), NULL);
	self->URI = (g_free (self->URI), NULL);
	G_OBJECT_CLASS (xml_namespace_parent_class)->dispose (obj);
}


GType xml_namespace_get_type (void) {
	static GType xml_namespace_type_id = 0;
	if (G_UNLIKELY (xml_namespace_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (XmlNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) xml_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (XmlNamespace), 0, (GInstanceInitFunc) xml_namespace_instance_init };
		xml_namespace_type_id = g_type_register_static (G_TYPE_OBJECT, "XmlNamespace", &g_define_type_info, 0);
	}
	return xml_namespace_type_id;
}
